@@ -161,6 +161,10 @@ from ncbi.datasets.openapi.model.v1_protein import V1Protein
 from ncbi.datasets.openapi.model.v1_protein import V1Protein as V1alpha1Protein
 from ncbi.datasets.openapi.model.v1_range import V1Range
 from ncbi.datasets.openapi.model.v1_range import V1Range as V1alpha1Range
+from ncbi.datasets.openapi.model.v1_ref_gene_catalog_dataset_request import V1RefGeneCatalogDatasetRequest
+from ncbi.datasets.openapi.model.v1_ref_gene_catalog_dataset_request import V1RefGeneCatalogDatasetRequest as V1alpha1RefGeneCatalogDatasetRequest
+from ncbi.datasets.openapi.model.v1_ref_gene_catalog_dataset_request_file_type import V1RefGeneCatalogDatasetRequestFileType
+from ncbi.datasets.openapi.model.v1_ref_gene_catalog_dataset_request_file_type import V1RefGeneCatalogDatasetRequestFileType as V1alpha1RefGeneCatalogDatasetRequestFileType
 from ncbi.datasets.openapi.model.v1_sars2_protein_dataset_request import V1Sars2ProteinDatasetRequest
 from ncbi.datasets.openapi.model.v1_sars2_protein_dataset_request import V1Sars2ProteinDatasetRequest as V1alpha1Sars2ProteinDatasetRequest
 from ncbi.datasets.openapi.model.v1_sci_name_and_ids import V1SciNameAndIds
